#! /usr/bin/env lua

--[[
	Similar to xgettext. Extracts string to be translated.
	
	@usage ./ExtractText *.lua Widgets/*.lua > pt_BR.po
	@author Lucas Hermann Negri
--]]

-- Set of translation strings
local trans = {}

-- Read the input files
for index = 1, #arg do
	local ln = 1

	-- Extraction
	local input = io.open(arg[index])

	for line in input:lines() do
		local i1, i2 = line:find([[_%(%"[^%)]+%"%)]])
	
		if i1 and i2 then
			local msg = line:sub(i1 + 3, i2 - 2)
			trans[msg] = trans[msg] or {}
			table.insert(trans[msg], string.format("%s:%i", arg[index], ln))
		end
		
		ln = ln + 1
	end
	
	input:close()
end

-- Output

-- Header
local cyear = os.date("%Y")
local cdate = os.date("%Y-%m-%d %H:%M-0300")
print(string.format([[
# Portuguese translations for PACKAGE package.
# Copyright (C) %s THE PACKAGE'S COPYRIGHT HOLDER
# This file is distributed under the same license as the PACKAGE package.
# Lucas Hermann Negri <kkndrox@gmail.com>, %s.
#
msgid ""
msgstr ""
"Project-Id-Version: PACKAGE VERSION\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: %s\n"
"PO-Revision-Date: %s\n"
"Last-Translator: Lucas Hermann Negri <kkndrox@gmail.com>\n"
"Language-Team: Brazilian Portuguese\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Plural-Forms: nplurals=2; plural=(n > 1);\n"	
]], cyear, cyear, cdate, cdate))

-- Messages
for msg, info in pairs(trans) do
	print(string.format([[#: %s]], table.concat(info, " ")))
	print(string.format([[msgid "%s"]], msg))
	print([[msgstr ""]])
	print()
end
