#! /usr/bin/env lua

-- Simple build script
ex		= function(arg) print(">>", arg) os.execute(arg) end
cc		= "gcc -pipe"
shared	= "gcc -shared"
flags	= ""
libs	= "-lm -ldl -llua"
rm		= "rm -rf"
mv		= "mv"
cp		= "cp"
cmd		= arg[1]
par1	= arg[2]
par2	= arg[3]
opt		= "-Wall -ansi"
name	= "lcl"
ext		= ".so"
sep		= "/"
mkdir	= "mkdir -p"
lua		= "lua"
luadir  = "/usr/share/lua/5.1"
luacdir = "/usr/lib/lua/5.1"
include = "/usr/include"

if par1 == "debug" then
	opt	= opt .. " -O0 -g -DIDEBUG"
elseif par1 == "size" then
	opt	= opt .. " -Os -fpic"
elseif par1 == "speed" then
	opt	= opt .. " -O3 -march=i686 -mtune=i686"
end

function buildlib()
	print("Building shared library...")
	ex(mkdir .. " out")
	ex(cc .. " " .. opt .. " " .. flags .. " src/*.c -c")
	ex(shared .. " " .. opt .. " *.o " .. libs .. " -o _" .. name .. ext)
	if par1 ~= "debug" then ex("strip _" .. name .. ext) end
	ex(mv .. " _" .. name .. ext .. " out")
	ex(cp .. " src/" .. name .. ".lua" .. " out")
end

function clean()
	ex(rm .. " out *.o")
end

function help()
	print("Commands:\n")
	for i, _ in pairs(commands) do
		io.write(i .. " ")
	end

	print("\n")
end

function install()
	print("Installing library...")
	ex(cp .. " out" .. sep .. "_" .. name .. ext .. " " .. luacdir)
	ex(cp .. " out" .. sep .. name .. ".lua " .. luadir)
	ex(mkdir .. " " .. include .. sep .. name)
	ex(cp .. " src" .. sep .. "*.h " .. include .. sep .. name)
end

function uninstall()
	print("Uninstalling..")
	ex(rm .. " " .. luacdir .. name .. ext)
	ex(rm .. " " .. luadir .. name .. ".lua")
	ex(rm .. " " .. include .. sep .. name)
end

commands = {
	["build"] = buildlib,
	["clean"] = clean,
	["install"] = install,
	["uninstall"] = uninstall,
	["help"] = help,
}

if not commands[cmd] then cmd = "help" end
commands[cmd]()

print("End.")

