/*
	This file is part of lcl.

	lcl is free software: you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	lcl is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with lcl.  If not, see <http://www.gnu.org/licenses/>.
	
	Copyright (C) 2008 Lucas Hermann Negri
*/

#include "locale.h"

static struct lconv *locale = NULL;

static void retCh(lua_State* L, const char ch)
{
	char b[1];
	b[0] = ch;
	lua_pushlstring(L, b, 1);
}

void init_locale()
{
	locale = localeconv();
}

int lcl_set_locale(lua_State* L)
{
	int top = lua_gettop(L), type;
	char* name;
	
	if(top > 1)
	{
		luaL_checktype(L, 1, LUA_TNUMBER);
		luaL_checktype(L, 2, LUA_TSTRING);
		type = lua_tointeger(L, 1);
		name = (char*)lua_tostring(L, 2);
	}
	else
	{
		type = LC_ALL;
		name = "";
	}
	
	char* res = setlocale(type, name);
	lua_pushstring(L, res);
	
	/* Get the current locale */
	locale = localeconv();
	
	return 1;
}

int lcl_get_field(lua_State* L)
{	
	int top = lua_gettop(L), i;
	
	for(i = 1; i <= top; ++i)
	{
		int field = luaL_checkinteger(L, i);
		
		switch(field)
		{
			case CURRENCY_SYMBOL:		lua_pushstring(L, locale->currency_symbol); break;
			case DECIMAL_POINT: 		lua_pushstring(L, locale->decimal_point);	break;
			case FRAC_DIGITS: 			retCh(L, locale->frac_digits);		break;
			case GROUPING:				lua_pushstring(L, locale->grouping);		break;
			case INT_CURR_SYMBOL: 		lua_pushstring(L, locale->int_curr_symbol);	break;
			case INT_FRAC_DIGITS: 		retCh(L, locale->int_frac_digits);	break;
			case MON_DECIMAL_POINT: 	lua_pushstring(L, locale->mon_decimal_point); break;
			case MON_GROUPING: 			lua_pushstring(L, locale->mon_grouping);	break;
			case MON_THOUSANDS_SEP: 	lua_pushstring(L, locale->mon_thousands_sep); break;
			case NEGATIVE_SIGN: 		lua_pushstring(L, locale->negative_sign);	break;
			case N_CS_PRECEDES: 		retCh(L, locale->n_cs_precedes);	break;
			case N_SEP_BY_SPACE: 		retCh(L, locale->n_sep_by_space);	break;
			case N_SIGN_POSN: 			retCh(L, locale->n_sign_posn);		break;
			case POSITIVE_SIGN: 		lua_pushstring(L, locale->positive_sign);	break;
			case P_CS_PRECEDES: 		retCh(L, locale->p_cs_precedes);	break;
			case P_SEP_BY_SPACE: 		retCh(L, locale->p_sep_by_space);	break;
			case P_SIGN_POSN: 			retCh(L, locale->p_sign_posn);		break;
			case THOUSANDS_SEP: 		lua_pushstring(L, locale->thousands_sep);	break;
			default: lua_pushnil(L);
		}
	}
	
	return top;
}
